@@ -61,7 +61,7 @@ class kVmSaverInterface : public KScreenSaverInterface
 
 public:
     virtual KAboutData* aboutData() {
-        return new KAboutData( "kvm.kss", 0, ki18n( "Virtual Machine" ), "2.2.0", ki18n( "Virtual Machine" ) );
+        return new KAboutData( "kvm.kss", "klock", ki18n( "Virtual Machine" ), "2.2.0", ki18n( "Virtual Machine" ) );
     }
 
 
@@ -93,7 +93,7 @@ load_images (m_state *state)
     }
   else
     {
-      state->images = QBitmap( vm_width, vm_height, vm_bits );
+      state->images = QBitmap::fromData( QSize(vm_width, vm_height), vm_bits );
     }
   state->image_width = state->images.width();
   state->image_height = state->images.height();
@@ -190,7 +190,11 @@ kVmSaver::kVmSaver( WId id ) : KScreenSaver( id )
 {
 	readSettings();
 
-        setBackgroundColor( Qt::black );
+        QPalette palette;
+        palette.setColor( backgroundRole(), Qt::black );
+        setPalette( palette );
+	setAutoFillBackground(true);
+
         setSpeed( speed );
         setRefreshTimeout( refreshTimeout );
 
@@ -200,7 +204,7 @@ kVmSaver::kVmSaver( WId id ) : KScreenSaver( id )
         vm_default_initstate( time(0), &(pool_state->pool->vm_random_data) );
 	connect( &timer, SIGNAL( timeout() ), SLOT( update() ) );
         timer.start( 100 - speed );
-        update();
+        show();
 }
 
 kVmSaver::~kVmSaver()
@@ -213,8 +217,8 @@ kVmSaver::~kVmSaver()
 void kVmSaver::setSpeed( int spd )
 {
 	speed = spd;
-//	timer.changeInterval( (100 - speed)*(100 - speed)*(100 - speed)/10000 );
-	timer.changeInterval( (100 - speed) );
+//	timer.start( (100 - speed)*(100 - speed)*(100 - speed)/10000 );
+	timer.start( (100 - speed) );
 }
 void kVmSaver::setRefreshTimeout( const int refreshTimeout )
 {
@@ -284,7 +288,8 @@ kVmSetup::kVmSetup( QWidget *parent )
 	QWidget *main = new QWidget(this);
 	setMainWidget(main);
 
-	QHBoxLayout *tl = new QHBoxLayout( main, 0, spacingHint() );
+	QHBoxLayout *tl = new QHBoxLayout( main );
+        tl->setSpacing( spacingHint() );
 	QVBoxLayout *tl1 = new QVBoxLayout();
 	tl->addLayout(tl1);
 
@@ -294,7 +299,8 @@ kVmSetup::kVmSetup( QWidget *parent )
 	QSlider *slider = new QSlider( Qt::Horizontal, main );
 	slider->setMinimumSize( 120, 20 );
 	slider->setRange( 0, 100 );
-	slider->setSteps( 10, 20 );
+        slider->setSingleStep( 10 );
+	slider->setPageStep( 20 );
 	slider->setTickPosition( QSlider::TicksBelow );
 	slider->setTickInterval( 10 );
 	slider->setValue( speed );
@@ -308,7 +314,8 @@ kVmSetup::kVmSetup( QWidget *parent )
 	slider = new QSlider( Qt::Horizontal, main );
 	slider->setMinimumSize( 120, 20 );
 	slider->setRange( 0, MAX_REFRESH_TIMEOUT );
-	slider->setSteps( MAX_REFRESH_TIMEOUT/10, MAX_REFRESH_TIMEOUT/5 );
+	slider->setSingleStep( MAX_REFRESH_TIMEOUT/10 );
+	slider->setPageStep( MAX_REFRESH_TIMEOUT/5 );
 	slider->setTickPosition( QSlider::TicksBelow );
 	slider->setTickInterval( MAX_REFRESH_TIMEOUT/10 );
 	slider->setValue( MAX_REFRESH_TIMEOUT - refreshTimeout );
