@@ -10,7 +10,7 @@
   rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
   sell copies of the Software, and to permit persons to whom the Software is
   furnished to do so, subject to the following conditions:
- 
+
   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.
 
@@ -25,7 +25,7 @@
 #include "config.h"
 #include <unistd.h> // for usleep
 #include <math.h>
-
+#include <QWidget>
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qdrawutil.h>
@@ -33,6 +33,16 @@
 #include <qimage.h>
 #include <qlabel.h>
 #include <qpixmap.h>
+//Added by qt3to4:
+#include <QPaintEvent>
+#include <Q3PointArray>
+#include <QEvent>
+#include <QBoxLayout>
+#include <Q3ValueList>
+#include <QShowEvent>
+#include <QVBoxLayout>
+#include <QResizeEvent>
+#include <QMouseEvent>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -51,7 +61,7 @@ static uint openLookMargin = 5;
 static const uint openLookTextVMargin = 1;
 static uint titleHeight;
 
-// --------------------------------------- 
+// ---------------------------------------
 
 DecorationFactory::DecorationFactory()
 {
@@ -86,26 +96,25 @@ bool DecorationFactory::supports( Ability ability )
     };
 }
 
-QValueList< DecorationFactory::BorderSize > 
-DecorationFactory::borderSizes() const
-{ 
+QList< DecorationFactory::BorderSize > DecorationFactory::borderSizes() const
+{
     // the list must be sorted
-    return QValueList< BorderSize >() << BorderNormal << 
-	BorderLarge << BorderVeryLarge <<  BorderHuge << 
+    return QList< BorderSize >() << BorderNormal <<
+	BorderLarge << BorderVeryLarge <<  BorderHuge <<
 	BorderVeryHuge << BorderOversized;
 }
 
-// --------------------------------------- 
+// ---------------------------------------
 
 static inline const KDecorationOptions* options()
 {
     return KDecoration::options();
 }
 
-// --------------------------------------- 
+// ---------------------------------------
 
-OpenLook::OpenLook(KDecorationBridge *b, KDecorationFactory *f) : 
-    KDecoration(b, f), 
+OpenLook::OpenLook(KDecorationBridge *b, KDecorationFactory *f) :
+    KDecoration(b, f),
     titleSpacer_    (0),
     mousePressPoint_(0, 0), // Anywhere outside button rect.
     buttonDown_     (false)
@@ -114,12 +123,14 @@ OpenLook::OpenLook(KDecorationBridge *b, KDecorationFactory *f) :
 
 void OpenLook::init()
 {
-  static const int SUPPORTED_WINDOW_TYPES_MASK = NET::NormalMask | 
-    NET::DesktopMask | NET::DockMask | NET::ToolbarMask | NET::MenuMask | 
-    NET::DialogMask | NET::OverrideMask | NET::TopMenuMask | 
+  static const int SUPPORTED_WINDOW_TYPES_MASK = NET::NormalMask |
+    NET::DesktopMask | NET::DockMask | NET::ToolbarMask | NET::MenuMask |
+    NET::DialogMask | NET::OverrideMask | NET::TopMenuMask |
     NET::UtilityMask | NET::SplashMask;
 
-  createMainWidget(WStaticContents | WResizeNoErase | WRepaintNoErase);
+  createMainWidget( Qt::WResizeNoErase);
+  widget()->setAttribute( Qt::WA_StaticContents);
+  widget()->setAttribute( Qt::WA_NoBackground );
   widget()->installEventFilter(this);
   widget()->setBackgroundMode(NoBackground);
   NET::WindowType type = windowType(SUPPORTED_WINDOW_TYPES_MASK);
@@ -127,7 +138,7 @@ void OpenLook::init()
   QFontMetrics fm(options()->font(isActive(), tool_));
 
   titleHeight = fm.height() + openLookTextVMargin * 2;
-  
+
   switch(KDecoration::options()->preferredBorderSize(factory())) {
       case KDecoration::BorderLarge:
           openLookMargin = 9;
@@ -151,7 +162,7 @@ void OpenLook::init()
   openLookCornerSize = 2*openLookMargin + 1;
   if (titleHeight <= openLookMargin)
       titleHeight = openLookMargin+1;
-  
+
   doLayout();
 }
 
@@ -173,9 +184,6 @@ bool OpenLook::eventFilter(QObject *o, QEvent *e)
   case QEvent::MouseButtonDblClick:
     mouseDoubleClickEvent(static_cast< QMouseEvent* >(e));
     return true;
-  case QEvent::Wheel:
-    wheelEvent( static_cast< QWheelEvent* >( e ));
-    return true;
   case QEvent::MouseButtonPress:
     if (!isButtonPress(static_cast< QMouseEvent* >(e))) {
       processMousePressEvent(static_cast< QMouseEvent* >(e));
@@ -196,7 +204,7 @@ bool OpenLook::eventFilter(QObject *o, QEvent *e)
   return false;
 }
 
-  void 
+  void
 OpenLook::borders(int &left, int &right, int &top, int &bottom) const
 {
     // FRAME XXX Check
@@ -210,7 +218,7 @@ OpenLook::captionChange()
   widget()->update(titleRect());
 }
 
-  void 
+  void
 OpenLook::shadeChange()
 {
 }
@@ -219,10 +227,10 @@ QSize OpenLook::minimumSize() const
 {
     int left, right, top, bottom;
     borders(left, right, top, bottom);
-    return QSize(left  + right + 2 * titleHeight, top + bottom); 
+    return QSize(left  + right + 2 * titleHeight, top + bottom);
 }
 
-  void 
+  void
 OpenLook::resize(const QSize& s)
 {
     widget()->resize(s);
@@ -252,9 +260,9 @@ OpenLook::paintEvent(QPaintEvent * pe)
   QBrush titleBackground(options()->color(KDecoration::ColorTitleBar, true));
 
   if (isActive())
-    qDrawShadePanel(&p, tr, widget()->colorGroup(), true, 1, &titleBackground);
+    qDrawShadePanel(&p, tr, widget()->palette(), true, 1, &titleBackground);
   else
-    p.fillRect(tr, widget()->colorGroup().brush(QColorGroup::Background));
+    p.fillRect(tr, widget()->palette().brush(QPalette::Background));
 
   p.setClipRegion(clipRegion);
 
@@ -266,7 +274,7 @@ OpenLook::paintEvent(QPaintEvent * pe)
 
   tr.setLeft(openLookCornerSize + 3 + buttonRect().width() + 2);
 
-  p.drawText(tr, AlignCenter, caption());
+  p.drawText(tr, Qt::AlignCenter, caption());
 }
 
   void
@@ -278,22 +286,13 @@ OpenLook::showEvent(QShowEvent *)
   void
 OpenLook::mouseDoubleClickEvent(QMouseEvent * e)
 {
-  if (e->button() == LeftButton && titleRect().contains(e->pos()))
+  if (e->button() == Qt::LeftButton && titleRect().contains(e->pos()))
   {
 	  titlebarDblClickOperation();
   }
 }
 
   void
-OpenLook::wheelEvent(QWheelEvent *e)
-{
-  if (isSetShade() || titleRect().contains(e->pos()))
-  {
-          titlebarMouseWheelOperation( e->delta());
-  }
-}
-
-  void 
 OpenLook::resizeEvent(QResizeEvent* e)
 {
   widget()->update();
@@ -320,17 +319,17 @@ OpenLook::mousePosition(const QPoint & p) const
     return PositionCenter;
 }
 
-  void 
+  void
 OpenLook::iconChange()
 {
 }
 
-  void 
+  void
 OpenLook::desktopChange()
 {
 }
 
-  void 
+  void
 OpenLook::maximizeChange()
 {
     widget()->repaint(false);
@@ -354,18 +353,18 @@ OpenLook::doLayout()
 
   layout->addSpacing(2);
 
-  QBoxLayout * midLayout = 
+  QBoxLayout * midLayout =
     new QBoxLayout(layout, QBoxLayout::LeftToRight, 0, 0);
- 
+
   if (isPreview()) {
     midLayout->addWidget(new QLabel(
-          i18n("<center><b>OpenLook preview</b></center>"), 
-          widget()), 
+          i18n("<center><b>OpenLook preview</b></center>"),
+          widget()),
         1);
   } else {
     midLayout->addItem( new QSpacerItem( 0, 0 ));
   }
-      
+
 }
 
   bool
@@ -482,7 +481,7 @@ OpenLook::paintTopLeftRect(QPainter & p) const
   int x2(r.right());
   int y2(r.bottom());
 
-  p.setPen(widget()->colorGroup().light());
+  p.setPen(widget()->palette().light());
 
   p.drawLine(x1, y1, x2, y1);
   p.drawLine(x1, y1 + 1, x1, y2);
@@ -490,7 +489,7 @@ OpenLook::paintTopLeftRect(QPainter & p) const
   p.fillRect(x1 + 1, y1 + 1, r.width()-2, openLookMargin-2,  handleColour);
   p.fillRect(x1 + 1, y1 + 1, openLookMargin-2, r.height()-2, handleColour);
 
-  p.setPen(widget()->colorGroup().dark());
+  p.setPen(widget()->palette().dark());
 
   p.drawLine(x2, y1 + 1, x2, y1 + openLookMargin-1);
 
@@ -513,7 +512,7 @@ OpenLook::paintTopRightRect(QPainter & p) const
   int x2(r.right());
   int y2(r.bottom());
 
-  p.setPen(widget()->colorGroup().light());
+  p.setPen(widget()->palette().light());
 
   p.drawLine(x1, y1, x2, y1);
   p.drawLine(x1, y1 + 1, x1, y1 + openLookMargin-1);
@@ -522,7 +521,7 @@ OpenLook::paintTopRightRect(QPainter & p) const
   p.fillRect(x1 + 1, y1 + 1, r.width()-2, openLookMargin-2, handleColour);
   p.fillRect(x2 - openLookMargin + 2, y1 + 1, openLookMargin-2, r.height()-2, handleColour);
 
-  p.setPen(widget()->colorGroup().dark());
+  p.setPen(widget()->palette().dark());
 
   p.drawLine(x1 + 1, y1 + openLookMargin-1, x2 - openLookMargin+1, y1 + openLookMargin-1);
   p.drawLine(x2, y1 + 1, x2, y2);
@@ -541,7 +540,7 @@ OpenLook::paintBottomLeftRect(QPainter & p) const
   int x2(r.right());
   int y2(r.bottom());
 
-  p.setPen(widget()->colorGroup().light());
+  p.setPen(widget()->palette().light());
 
   p.drawLine(x1, y1, x1 + openLookMargin-1, y1);
   p.drawLine(x1, y1 + 1, x1, y2);
@@ -550,7 +549,7 @@ OpenLook::paintBottomLeftRect(QPainter & p) const
   p.fillRect(x1 + 1, y2 - openLookMargin + 2, r.width()-2, openLookMargin-2, handleColour);
   p.fillRect(x1 + 1, y1 + 1, openLookMargin-2, r.height()-2, handleColour);
 
-  p.setPen(widget()->colorGroup().dark());
+  p.setPen(widget()->palette().dark());
 
   p.drawLine(x1 + openLookMargin-1, y1 + 1, x1 + openLookMargin-1, y2 - openLookMargin);
   p.drawLine(x1 + 1, y2, x2, y2);
@@ -569,7 +568,7 @@ OpenLook::paintBottomRightRect(QPainter & p) const
   int x2(r.right());
   int y2(r.bottom());
 
-  p.setPen(widget()->colorGroup().light());
+  p.setPen(widget()->palette().light());
 
   p.drawLine(x1, y2 - openLookMargin+1, x1, y2);
   p.drawLine(x1 + 1, y2 - openLookMargin+1, x2 - openLookMargin+1, y2 - openLookMargin+1);
@@ -579,7 +578,7 @@ OpenLook::paintBottomRightRect(QPainter & p) const
   p.fillRect(x1 + 1, y2 - openLookMargin + 2, r.width()-2, openLookMargin-2,  handleColour);
   p.fillRect(x2 - openLookMargin + 2, y1 + 1, openLookMargin-2, r.height()-2, handleColour);
 
-  p.setPen(widget()->colorGroup().dark());
+  p.setPen(widget()->palette().dark());
 
   p.drawLine(x1 + 1, y2, x2, y2);
   p.drawLine(x2, y1 + 1, x2, y2 - 1);
@@ -609,16 +608,16 @@ OpenLook::paintButton(QPainter & p) const
      r.width() - 2,
      r.height() - 2,
      buttonDown_
-     ? widget()->colorGroup().dark()
+     ? widget()->palette().dark()
      : options()->color(KDecoration::ColorButtonBg, isActive())
     );
 
-  p.setPen(buttonDown_ ? widget()->colorGroup().dark() : widget()->colorGroup().light());
+  p.setPen(buttonDown_ ? widget()->palette().dark() : widget()->palette().light());
 
   p.drawLine(r.left() + 1, r.top(), r.right() - 1, r.top());
   p.drawLine(r.left(), r.top() + 1, r.left(), r.bottom() - 1);
 
-  p.setPen(buttonDown_ ? widget()->colorGroup().light() : widget()->colorGroup().dark());
+  p.setPen(buttonDown_ ? widget()->palette().light() : widget()->palette().dark());
 
   p.drawLine(r.right(), r.top() + 1, r.right(), r.bottom() - 1);
   p.drawLine(r.left() + 1, r.bottom(), r.right() - 1, r.bottom());
@@ -636,9 +635,9 @@ OpenLook::paintArrow(QPainter & p) const
   int w = br.width()  - 10;
   int h = br.height() - 10;
 
-  QPointArray poly(3);
+  Q3PointArray poly(3);
 
-  p.setBrush(widget()->colorGroup().mid());
+  p.setBrush(widget()->palette().mid());
 
   poly.setPoint(0, x, y);
   poly.setPoint(1, x + w - 1, y);
@@ -646,13 +645,13 @@ OpenLook::paintArrow(QPainter & p) const
 
   p.drawPolygon(poly);
 
-  p.setPen(widget()->colorGroup().dark());
+  p.setPen(widget()->palette().dark());
 
   p.drawLine(x, y, x + w - 1, y);
 
   p.drawLine(x, y, x + (w / 2), y + h - 1);
 
-  p.setPen(widget()->colorGroup().light());
+  p.setPen(widget()->palette().light());
 
   p.drawLine(x + (w / 2), y + h - 1, x + w - 1, y);
 }
@@ -669,10 +668,10 @@ OpenLook::paintBorder(QPainter & p) const
   uint r = widget()->rect().right();
   uint b = widget()->rect().bottom();
 
-  p.fillRect(x + cs, y, w - cs - cs, 2,     widget()->colorGroup().shadow());
-  p.fillRect(x + cs, b - 1, w - cs - cs, 2, widget()->colorGroup().shadow());
-  p.fillRect(x, y + cs, 2, h - cs - cs,     widget()->colorGroup().shadow());
-  p.fillRect(r - 1, y + cs, 2, h - cs - cs, widget()->colorGroup().shadow());
+  p.fillRect(x + cs, y, w - cs - cs, 2,     widget()->palette().shadow());
+  p.fillRect(x + cs, b - 1, w - cs - cs, 2, widget()->palette().shadow());
+  p.fillRect(x, y + cs, 2, h - cs - cs,     widget()->palette().shadow());
+  p.fillRect(r - 1, y + cs, 2, h - cs - cs, widget()->palette().shadow());
 
   QColor frameColour(options()->color(KDecoration::ColorFrame, isActive()));
 
@@ -687,7 +686,7 @@ OpenLook::paintBorder(QPainter & p) const
      titleRect().bottom() + 1,
      width() - 2 * openLookMargin,
      2,
-     widget()->colorGroup().background()
+     widget()->palette().background()
     );
 }
 
