@@ -1,3 +1,18 @@
+/********************************************************************
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*********************************************************************/
+
 #include "systemclient.h"
 
 #include <qlayout.h>
@@ -6,6 +21,16 @@
 #include <qtooltip.h>
 #include <qlabel.h>
 #include <qcursor.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QPaintEvent>
+#include <QGridLayout>
+#include <QEvent>
+#include <QBoxLayout>
+#include <Q3ValueList>
+#include <QShowEvent>
+#include <QResizeEvent>
+#include <QMouseEvent>
 
 #include <kpixmapeffect.h>
 #include <kdrawutil.h>
@@ -13,9 +38,6 @@
 #include <kapplication.h>
 #include <kdebug.h>
 
-// Default button layout
-const char default_left[]  = "X";
-const char default_right[] = "HSIA";
 
 namespace System {
 
@@ -29,8 +51,8 @@ static unsigned char r_minmax_bits[] = {
     0x0c, 0x18, 0x33, 0x67, 0xcf, 0x9f, 0x3f, 0x3f};
 
 static unsigned char l_minmax_bits[] = {
-    0x30, 0x18, 0xcc, 0xe6, 0xf3, 0xf9, 0xfc, 0xfc};    
-    
+    0x30, 0x18, 0xcc, 0xe6, 0xf3, 0xf9, 0xfc, 0xfc};
+
 static unsigned char unsticky_bits[] = {
     0x00, 0x18, 0x18, 0x7e, 0x7e, 0x18, 0x18, 0x00};
 
@@ -164,7 +186,7 @@ static void create_pixmaps()
         iBtnPixDown = new KPixmap;
         iBtnPixDown->resize(14, 14);
         bitBlt(iBtnPixDown, 2, 2, &iPix, 0, 0, 10, 10, Qt::CopyROP, true);
-        drawButtonFrame(iBtnPixDown, KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame,
+        drawButtonFrame(iBtnPixDown, options()->colorGroup(KDecorationOptions::ColorFrame,
                                                          false));
     }
     if(qGray(KDecoration::options()->color(KDecorationOptions::ColorButtonBg, true).rgb()) > 128)
@@ -189,36 +211,66 @@ static void delete_pixmaps()
 }
 
 SystemButton::SystemButton(SystemClient *parent, const char *name,
-                           const unsigned char *bitmap, const QString& tip)
-: QButton(parent->widget(), name)
+                           const unsigned char *bitmap)
+: KCommonDecorationButton(parent->widget(), name)
 {
-   setTipText(tip);
-   setBackgroundMode( NoBackground );
-   setCursor(ArrowCursor);
+   setBackgroundMode( Qt::NoBackground );
+   setCursor(Qt::ArrowCursor);
    resize(14, 14);
    if(bitmap)
       setBitmap(bitmap);
    client = parent;
 }
 
-void SystemButton::setTipText(const QString &tip)
-{
-   if (KDecoration::options()->showTooltips())
-   {
-      QToolTip::remove(this );
-      QToolTip::add(this, tip );
-   }
-}
-
 
 QSize SystemButton::sizeHint() const
 {
     return(QSize(14, 14));
 }
 
-void SystemButton::reset()
+void SystemButton::reset(unsigned long changed)
 {
-   repaint(false);
+  if (changed&DecorationReset || changed&ManualReset || changed&SizeChange || changed&StateChange) {
+    switch (type() ) {
+      case CloseButton:
+        setBitmap(close_bits);
+        break;
+      case HelpButton:
+        setBitmap(question_bits);
+        break;
+      case MinButton:
+        setBitmap(iconify_bits);
+        break;
+      case MaxButton:
+        setBitmap( isOn() ? unmaximize_bits : maximize_bits );
+        break;
+      case OnAllDesktopsButton:
+        setBitmap( isOn() ? unsticky_bits : sticky_bits );
+        break;
+      case ShadeButton:
+        setBitmap( isOn() ? shade_on_bits : shade_off_bits );
+        break;
+      default:
+        setBitmap(0);
+        break;
+    }
+
+    this->update();
+  }
+#if 0
+  static unsigned char iconify_bits[] = {
+    0x00, 0x00, 0xff, 0xff, 0x7e, 0x3c, 0x18, 0x00};
+
+static unsigned char maximize_bits[] = {
+    0x00, 0x18, 0x3c, 0x7e, 0xff, 0xff, 0x00, 0x00};
+
+static unsigned char r_minmax_bits[] = {
+    0x0c, 0x18, 0x33, 0x67, 0xcf, 0x9f, 0x3f, 0x3f};
+
+static unsigned char l_minmax_bits[] = {
+    0x30, 0x18, 0xcc, 0xe6, 0xf3, 0xf9, 0xfc, 0xfc};
+
+#endif
 }
 
 void SystemButton::setBitmap(const unsigned char *bitmap)
@@ -237,7 +289,7 @@ void SystemButton::drawButton(QPainter *p)
             p->drawPixmap(0, 0, isDown() ? *iBtnPixDown : *iBtnPix);
     }
     else{
-        QColorGroup g = KDecoration::options()->colorGroup(KDecorationOptions::ColorFrame,
+        QColorGroup g = KDecoration::options()->color(KDecorationOptions::ColorFrame,
                                             client->isActive());
         int x2 = width()-1;
         int y2 = height()-1;
@@ -268,194 +320,70 @@ void SystemButton::drawButton(QPainter *p)
     }
 }
 
-void SystemButton::mousePressEvent( QMouseEvent* e )
-{
-   last_button = e->button();
-   QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-   QButton::mousePressEvent( &me );
-}
-
-void SystemButton::mouseReleaseEvent( QMouseEvent* e )
-{
-   last_button = e->button();
-   QMouseEvent me ( e->type(), e->pos(), e->globalPos(), LeftButton, e->state() );
-   QButton::mouseReleaseEvent( &me );
-}
 
 
 
 SystemClient::SystemClient(KDecorationBridge* bridge, KDecorationFactory* factory)
-    : KDecoration(bridge, factory)
+    : KCommonDecoration(bridge, factory)
 {}
 
 SystemClient::~SystemClient()
 {
-    for (int n=0; n<ButtonTypeCount; n++) {
-        if (button[n]) delete button[n];
+}
+
+QString SystemClient::visibleName() const
+{
+    return i18n( "System++" );
+}
+
+QString SystemClient::defaultButtonsLeft() const
+{
+    return "X";
+}
+
+QString SystemClient::defaultButtonsRight() const
+{
+    return "HSIA";
+}
+
+KCommonDecorationButton *SystemClient::createButton(ButtonType type)
+{
+    switch (type) {
+        case OnAllDesktopsButton:
+            return new SystemButton(this, "sticky", NULL);
+
+        case HelpButton:
+            return new SystemButton(this, "help", question_bits);
+
+        case MinButton:
+            return new SystemButton(this, "iconify", iconify_bits);
+
+        case MaxButton:
+            return new SystemButton(this, "maximize", maximize_bits);
+
+        case CloseButton:
+            return new SystemButton(this, "close", NULL);
+
+
+        default:
+            return 0;
     }
 }
 
 void SystemClient::init()
 {
-   createMainWidget(0);
-   widget()->installEventFilter( this );
-
-   QGridLayout* g = new QGridLayout(widget(), 0, 0, 2);
-
-   if (isPreview())
-   {
-      g->addWidget(new QLabel(i18n("<center><b>System++ preview</b></center>"), widget()), 1, 1);
-   }
-   else
-   {
-      g->addItem(new QSpacerItem( 0, 0 ), 1, 1); // no widget in the middle
-   }
-//   g->addItem( new QSpacerItem( 0, 0, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
-   g->setRowStretch(1, 10);
-
-   g->addColSpacing(0, 2);
-   g->addColSpacing(2, 2);
-   g->addRowSpacing(2, 6);
-
-   QBoxLayout* hb = new QBoxLayout(0, QBoxLayout::LeftToRight, 0, 0, 0);
-   hb->setResizeMode(QLayout::FreeResize);
-   g->addLayout( hb, 0, 1 );
-   hb->addSpacing(3);   
-   
-   titlebar = new QSpacerItem(10, 14, QSizePolicy::Expanding,
-                              QSizePolicy::Minimum);    
-
-    // setup titlebar buttons
-    for (int n=0; n<ButtonTypeCount; n++) button[n] = 0;
-    addButtons(hb, KDecoration::options()->customButtonPositions() ? 
-                   KDecoration::options()->titleButtonsLeft() : QString(default_left));
-    hb->addSpacing(2);    
-    hb->addItem(titlebar);
-    hb->addSpacing(3);
-    addButtons(hb, KDecoration::options()->customButtonPositions() ? 
-                   KDecoration::options()->titleButtonsRight() : QString(default_right));
-    hb->addSpacing(2);
-
-   widget()->setBackgroundMode(QWidget::NoBackground);
-   recalcTitleBuffer();
+    //TODO ?????
+    KCommonDecoration::init();
 }
 
-void SystemClient::addButtons(QBoxLayout *hb, const QString& s)
+
+void SystemClient::reset(unsigned long changed)
 {
-    unsigned char *minmax_bits;
-    int l_max = KDecoration::options()->titleButtonsLeft().find('A');
-    if (s.length() > 0) {
-        for (unsigned n=0; n < s.length(); n++) {
-            switch (s[n]) {
-              case 'X': // Close button
-                  if ((!button[ButtonClose]) && isCloseable()) {
-                      button[ButtonClose] = new SystemButton(this, "close", NULL, i18n("Close"));
-                      connect( button[ButtonClose], SIGNAL( clicked() ), this, ( SLOT( closeWindow() ) ) );
-                      hb->addWidget(button[ButtonClose]);
-                      hb->addSpacing(1);
-                  }
-                  break;
-                  
-              case 'S': // Sticky button
-                  if (!button[ButtonSticky]) {
-                     button[ButtonSticky] = new SystemButton(this, "sticky", NULL, i18n("On all desktops"));
-                     if(isOnAllDesktops())
-                         button[ButtonSticky]->setBitmap(unsticky_bits);
-                     else
-                         button[ButtonSticky]->setBitmap(sticky_bits);
-                     connect( button[ButtonSticky], SIGNAL( clicked() ), this, ( SLOT( toggleOnAllDesktops() ) ) );
-                     hb->addWidget(button[ButtonSticky]);
-                     hb->addSpacing(1);
-                  }
-                  break;
-
-              case 'I': // Minimize button
-                  if ((!button[ButtonMinimize]) && isMinimizable())  {
-                      button[ButtonMinimize] = new SystemButton(this, "iconify", iconify_bits, i18n("Minimize"));
-                      connect( button[ButtonMinimize], SIGNAL( clicked() ), this, ( SLOT( minimize() ) ) );
-                      hb->addWidget(button[ButtonMinimize]);
-                      hb->addSpacing(1);
-                  }
-                  break;
-
-              case 'A': // Maximize button
-                  if ((!button[ButtonMaximize]) && isMaximizable()) {
-                      if (maximizeMode()==MaximizeFull) {
-                          if (KDecoration::options()->customButtonPositions() && (l_max>-1))
-                              minmax_bits = l_minmax_bits;
-                          else
-                              minmax_bits = r_minmax_bits;
-                          button[ButtonMaximize] = new SystemButton(this, "maximize", minmax_bits, i18n("Restore"));
-                      }
-                      else
-                          button[ButtonMaximize] = new SystemButton(this, "maximize", maximize_bits, i18n("Maximize"));
-                      connect( button[ButtonMaximize], SIGNAL( clicked() ), this, ( SLOT( maxButtonClicked() ) ) );
-                      hb->addWidget(button[ButtonMaximize]);
-                      hb->addSpacing(1);
-                  }
-                  break;
-
-              case 'H': // Help button
-                  if ((!button[ButtonHelp]) && providesContextHelp()) {
-                      button[ButtonHelp] = new SystemButton(this, "help", question_bits, i18n("Help"));
-                      connect( button[ButtonHelp], SIGNAL( clicked() ), this, ( SLOT( showContextHelp() ) ) );
-                      hb->addWidget(button[ButtonHelp]);
-                      hb->addSpacing(1);
-                  }
-                  break;
-            
-            }
-        }
-    }
-}
-
-bool SystemClient::eventFilter( QObject* o, QEvent* e )
-{
-    if( o != widget())
-       return false;
-    switch( e->type())
-    {
-    case QEvent::Resize:
-       resizeEvent(static_cast< QResizeEvent* >( e ) );
-       return true;
-    case QEvent::Paint:
-       paintEvent(static_cast< QPaintEvent* >( e ) );
-       return true;
-    case QEvent::MouseButtonDblClick:
-       mouseDoubleClickEvent(static_cast< QMouseEvent* >( e ) );
-       return true;
-    case QEvent::MouseButtonPress:
-       processMousePressEvent(static_cast< QMouseEvent* >( e ) );
-       return true;
-    case QEvent::Wheel:
-       wheelEvent( static_cast< QWheelEvent* >( e ));
-       return true;
-    default:
-        break;
-    }
-    return false;
-}
-
-void SystemClient::reset(unsigned long)
-{
-   titleBuffer.resize(0, 0);
-   recalcTitleBuffer();
-   widget()->repaint();
-   if (button[ButtonClose])
-       button[ButtonClose]->reset();
-   if (button[ButtonSticky])
-       button[ButtonSticky]->reset();
-   if (button[ButtonMinimize])
-       button[ButtonMinimize]->reset();
-   if (button[ButtonMaximize])
-       button[ButtonMaximize]->reset();
-   if (button[ButtonHelp])
-       button[ButtonHelp]->reset();
-}
-
-void SystemClient::maxButtonClicked()
-{
-   maximize( button[ButtonMaximize]->last_button );
+#if 0
+    titleBuffer.resize(0, 0);
+    recalcTitleBuffer();
+#endif
+    KCommonDecoration::reset(changed);
 }
 
 void SystemClient::resizeEvent( QResizeEvent* )
@@ -475,11 +403,6 @@ void SystemClient::resizeEvent( QResizeEvent* )
         }*/
 }
 
-void SystemClient::resize( const QSize& s )
-{
-   widget()->resize( s );
-}
-
 
 QSize SystemClient::minimumSize() const
 {
@@ -500,7 +423,7 @@ void SystemClient::recalcTitleBuffer()
     else
         p.fillRect(0, 0, width(), 18,
                    options()->colorGroup(KDecorationOptions::ColorFrame, true).
-                   brush(QColorGroup::Button));
+                   brush(QPalette::Button));
 
     QRect t = titlebar->geometry();
     t.setTop( 2 );
@@ -523,17 +446,12 @@ void SystemClient::recalcTitleBuffer()
     p.setFont(options()->font(true));
 
     p.drawText(t.x()+((t.width()-fm.width(caption()))/2)-4,
-               0, fm.width(caption())+8, 18, AlignCenter, caption());
+               0, fm.width(caption())+8, 18, Qt::AlignCenter, caption());
     p.setClipping(false);
     p.end();
     oldTitle = caption();
 }
 
-void SystemClient::captionChange()
-{
-   recalcTitleBuffer();
-   widget()->repaint(titlebar->geometry(), false);
-}
 
 void SystemClient::drawRoundFrame(QPainter &p, int x, int y, int w, int h)
 {
@@ -547,10 +465,10 @@ void SystemClient::paintEvent( QPaintEvent* )
     QPainter p(widget());
     QRect t = titlebar->geometry();
 
-    QBrush fillBrush(widget()->colorGroup().brush(QColorGroup::Background).pixmap() ?
-                     widget()->colorGroup().brush(QColorGroup::Background) :
-                     options()->colorGroup(KDecorationOptions::ColorFrame, isActive()).
-                     brush(QColorGroup::Button));
+    QBrush fillBrush(widget()->palette().brush(QPalette::Background).pixmap() ?
+                     widget()->palette().brush(QPalette::Background) :
+                     options()->color(KDecorationOptions::ColorFrame, isActive()).
+                     brush(QPalette::Button));
 
     p.fillRect(1, 18, width()-2, height()-19, fillBrush);
 
@@ -567,13 +485,13 @@ void SystemClient::paintEvent( QPaintEvent* )
             p.fillRect(0, 0, width(), 18, fillBrush);
         p.setPen(options()->color(KDecorationOptions::ColorFont, isActive()));
         p.setFont(options()->font(isActive()));
-        p.drawText(t, AlignCenter, caption() );
+        p.drawText(t, Qt::AlignCenter, caption() );
     }
 
-    p.setPen(options()->colorGroup(KDecorationOptions::ColorFrame, isActive()).light());
+    p.setPen(options()->color(KDecorationOptions::ColorFrame, isActive()).light());
     p.drawLine(width()-20, height()-7, width()-10,  height()-7);
     p.drawLine(width()-20, height()-5, width()-10,  height()-5);
-    p.setPen(options()->colorGroup(KDecorationOptions::ColorFrame, isActive()).dark());
+    p.setPen(options()->color(KDecorationOptions::ColorFrame, isActive()).dark());
     p.drawLine(width()-20, height()-6, width()-10,  height()-6);
     p.drawLine(width()-20, height()-4, width()-10,  height()-4);
 
@@ -607,58 +525,12 @@ void SystemClient::showEvent(QShowEvent *)
 
 void SystemClient::mouseDoubleClickEvent( QMouseEvent * e )
 {
-   if ( e->button() == LeftButton && titlebar->geometry().contains( e->pos() ) )
+   if ( e->button() == Qt::LeftButton && titlebar->geometry().contains( e->pos() ) )
       titlebarDblClickOperation();
 }
 
-void SystemClient::wheelEvent( QWheelEvent *e )
-{
-    if (isSetShade() || QRect( 0, 0, width(), titlebar->geometry().height() ).contains( e->pos() ) )
-        titlebarMouseWheelOperation( e->delta());
-}
 
-void SystemClient::maximizeChange()
-{
-    unsigned char *minmax_bits;
-    int l_max = KDecoration::options()->titleButtonsLeft().find('A');
-    if (KDecoration::options()->customButtonPositions() && (l_max>-1))
-        minmax_bits = l_minmax_bits;
-    else
-        minmax_bits = r_minmax_bits;
-    if (button[ButtonMaximize]) {
-        button[ButtonMaximize]->setBitmap((maximizeMode()==MaximizeFull) ? minmax_bits : maximize_bits);
-        button[ButtonMaximize]->setTipText((maximizeMode()==MaximizeFull) ? i18n("Restore") : i18n("Maximize"));
-    }
-}
 
-void SystemClient::activeChange()
-{
-    widget()->repaint(false);
-    if (button[ButtonClose])
-        button[ButtonClose]->reset();
-    if (button[ButtonSticky])
-        button[ButtonSticky]->reset();
-    if (button[ButtonMinimize])
-        button[ButtonMinimize]->reset();
-    if (button[ButtonMaximize])
-        button[ButtonMaximize]->reset();
-    if (button[ButtonHelp])
-        button[ButtonHelp]->reset();
-}
-
-void SystemClient::iconChange()
-{
-//   if (button[BtnMenu] && button[BtnMenu]->isVisible())
-//      button[BtnMenu]->repaint(false);
-}
-
-void SystemClient::desktopChange()
-{
-   if (button[ButtonSticky]) {
-       button[ButtonSticky]->setBitmap(isOnAllDesktops() ? unsticky_bits : sticky_bits);
-       button[ButtonSticky]->setTipText(isOnAllDesktops() ? i18n("Not on all desktops") : i18n("On all desktops"));
-   }
-}
 
 /*void SystemClient::stickyChange(bool on)
 {
@@ -722,9 +594,9 @@ bool SystemDecoFactory::supports( Ability ability )
     };
 }
 
-QValueList<KDecorationFactory::BorderSize> SystemDecoFactory::borderSizes() const
+QList<KDecorationFactory::BorderSize> SystemDecoFactory::borderSizes() const
 { // the list must be sorted
-   return QValueList< BorderSize >() << BorderNormal;
+   return Q3ValueList< BorderSize >() << BorderNormal;
 }
 
 }
